@@ -571,13 +571,14 @@ class fract:
     ((3+5j) / 3)
     """
     def __init__(self, mole, deno, reduct_fract_count = 1):
-        self.mole = mole
-        self.deno = deno
         if hmath_setting.fract.max_about_minute_limit < reduct_fract_count:
-            self.reduct_fract_count = 1
-            self = reduct_fract(self)
+            new_self  = reduct_fract(fract(mole, deno, 1))
+            self.mole = new_self.mole
+            self.deno = new_self.deno
             self.reduct_fract_count = 0
         else:
+            self.mole = mole
+            self.deno = deno
             self.reduct_fract_count = reduct_fract_count
     
     def __repr__(self):
